@@ -17,7 +17,8 @@ rasch_df_nest <- function(df, vars_group, vars_id) {
   #split data by age group and add back the max and min rows row
   df_nest <- df_nest %>% 
     group_by_at(vars_group) %>% 
-    tidyr::nest(.key = "df_split") %>% 
+    tidyr::nest() %>% 
+    rename(df_split = data) %>% 
     mutate(df_split = purrr::map(df_split, function(df_age) {
       df_age <- bind_rows(df_age,
                           df %>% filter(!!rlang::sym(vars_id) %in% c("MAX","MIN")))
